| Title: | Provides a Data Set on the Population in Japan |
|---|---|
| Description: | Information on the population and household registers, as published by the census and each local authority. The acquired data will be returned in a tidy format. |
| Authors: | Shinya Uryu [aut, cre] (ORCID: <https://orcid.org/0000-0002-0493-6186>) |
| Maintainer: | Shinya Uryu <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-31 09:56:45 UTC |
| Source: | https://github.com/uribo/jpops |
conv_gender_vars(x, lang = "ja")conv_gender_vars(x, lang = "ja")
x |
variable |
lang |
Specify the language to convert |
get_jinkou(year, appid = NULL, cache = TRUE, .area = "all") get_jinkou_age(year, appid = NULL, cache = TRUE, .area = "all")get_jinkou(year, appid = NULL, cache = TRUE, .area = "all") get_jinkou_age(year, appid = NULL, cache = TRUE, .area = "all")
year |
year |
appid |
application id |
cache |
save to cache |
.area |
Limit the output area. The default is "all". You can select "prefecture" and "city" as options. |